@@ -1,24 +1,24 @@
 #!/usr/bin/env python
-#******************************************************************************
-#  $Id: gcps2vec.py 28389 2015-01-30 19:26:09Z rouault $
-# 
+# ******************************************************************************
+#  $Id$
+#
 #  Project:  GDAL
 #  Purpose:  Convert GCPs to a point layer.
 #  Author:   Frank Warmerdam, warmerdam@pobox.com
-# 
-#******************************************************************************
+#
+# ******************************************************************************
 #  Copyright (c) 2005, Frank Warmerdam <warmerdam@pobox.com>
-# 
+#
 #  Permission is hereby granted, free of charge, to any person obtaining a
 #  copy of this software and associated documentation files (the "Software"),
 #  to deal in the Software without restriction, including without limitation
 #  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 #  and/or sell copies of the Software, and to permit persons to whom the
 #  Software is furnished to do so, subject to the following conditions:
-# 
+#
 #  The above copyright notice and this permission notice shall be included
 #  in all copies or substantial portions of the Software.
-# 
+#
 #  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 #  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 #  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
@@ -26,19 +26,15 @@
 #  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
-#******************************************************************************
-
-try:
-    from osgeo import gdal
-    from osgeo import ogr
-    from osgeo import osr
-except ImportError:
-    import gdal
-    import ogr
-    import osr
+# ******************************************************************************
 
 import sys
 
+from osgeo import gdal
+from osgeo import ogr
+from osgeo import osr
+
+
 def Usage():
     print('Usage: gcps2vec.py [-of <ogr_drivername>] [-p] <raster_file> <vector_file>')
     sys.exit(1)
@@ -47,15 +43,16 @@ def Usage():
 # 	Mainline
 # =============================================================================
 
+
 out_format = 'GML'
 in_file = None
 out_file = None
 pixel_out = 0
 
 gdal.AllRegister()
-argv = gdal.GeneralCmdLineProcessor( sys.argv )
+argv = gdal.GeneralCmdLineProcessor(sys.argv)
 if argv is None:
-    sys.exit( 0 )
+    sys.exit(0)
 
 # Parse command line arguments.
 i = 1
@@ -84,9 +81,9 @@ if out_file is None:
     Usage()
 
 # ----------------------------------------------------------------------------
-# Open input file, and fetch GCPs. 
+# Open input file, and fetch GCPs.
 # ----------------------------------------------------------------------------
-ds = gdal.Open( in_file )
+ds = gdal.Open(in_file)
 if ds is None:
     print('Unable to open %s' % in_file)
     sys.exit(1)
@@ -96,7 +93,7 @@ gcps = ds.GetGCPs()
 
 ds = None
 
-if gcps is None or len(gcps) == 0:
+if gcps is None or not gcps:
     print('No GCPs on file %s!' % in_file)
     sys.exit(1)
 
@@ -104,12 +101,12 @@ if gcps is None or len(gcps) == 0:
 # Create output file, and layer.
 # ----------------------------------------------------------------------------
 
-drv = ogr.GetDriverByName( out_format )
+drv = ogr.GetDriverByName(out_format)
 if drv is None:
     print('No driver named %s available.' % out_format)
     sys.exit(1)
 
-ds = drv.CreateDataSource( out_file )
+ds = drv.CreateDataSource(out_file)
 
 if pixel_out == 0 and gcp_srs != "":
     srs = osr.SpatialReference()
@@ -122,57 +119,55 @@ if pixel_out == 0:
 else:
     geom_type = ogr.wkbPoint
 
-layer = ds.CreateLayer( 'gcps', srs, geom_type = geom_type )
+layer = ds.CreateLayer('gcps', srs, geom_type=geom_type)
 
 if pixel_out == 0:
-    fd = ogr.FieldDefn( 'Pixel', ogr.OFTReal )
-    layer.CreateField( fd )
+    fd = ogr.FieldDefn('Pixel', ogr.OFTReal)
+    layer.CreateField(fd)
 
-    fd = ogr.FieldDefn( 'Line', ogr.OFTReal )
-    layer.CreateField( fd )
+    fd = ogr.FieldDefn('Line', ogr.OFTReal)
+    layer.CreateField(fd)
 else:
-    fd = ogr.FieldDefn( 'X', ogr.OFTReal )
-    layer.CreateField( fd )
+    fd = ogr.FieldDefn('X', ogr.OFTReal)
+    layer.CreateField(fd)
 
-    fd = ogr.FieldDefn( 'Y', ogr.OFTReal )
-    layer.CreateField( fd )
+    fd = ogr.FieldDefn('Y', ogr.OFTReal)
+    layer.CreateField(fd)
 
-    fd = ogr.FieldDefn( 'Z', ogr.OFTReal )
-    layer.CreateField( fd )
+    fd = ogr.FieldDefn('Z', ogr.OFTReal)
+    layer.CreateField(fd)
 
-fd = ogr.FieldDefn( 'Id', ogr.OFTString )
-layer.CreateField( fd )
+fd = ogr.FieldDefn('Id', ogr.OFTString)
+layer.CreateField(fd)
 
-fd = ogr.FieldDefn( 'Info', ogr.OFTString )
-layer.CreateField( fd )
+fd = ogr.FieldDefn('Info', ogr.OFTString)
+layer.CreateField(fd)
 
 # ----------------------------------------------------------------------------
-# Write GCPs. 
+# Write GCPs.
 # ----------------------------------------------------------------------------
 
 for gcp in gcps:
 
-    feat = ogr.Feature( layer.GetLayerDefn() )
+    feat = ogr.Feature(layer.GetLayerDefn())
 
     if pixel_out == 0:
-        geom = ogr.Geometry( geom_type )
-        feat.SetField( 'Pixel', gcp.GCPPixel )
-        feat.SetField( 'Line',  gcp.GCPLine )
-        geom.SetPoint( 0, gcp.GCPX, gcp.GCPY, gcp.GCPZ )
+        geom = ogr.Geometry(geom_type)
+        feat.SetField('Pixel', gcp.GCPPixel)
+        feat.SetField('Line', gcp.GCPLine)
+        geom.SetPoint(0, gcp.GCPX, gcp.GCPY, gcp.GCPZ)
     else:
-        geom = ogr.Geometry( geom_type )
-        feat.SetField( 'X', gcp.GCPX )
-        feat.SetField( 'Y',  gcp.GCPY )
-        feat.SetField( 'Z',  gcp.GCPZ )
-        geom.SetPoint( 0, gcp.GCPPixel, gcp.GCPLine )
-        
-    feat.SetField( 'Id',    gcp.Id )
-    feat.SetField( 'Info',  gcp.Info )
+        geom = ogr.Geometry(geom_type)
+        feat.SetField('X', gcp.GCPX)
+        feat.SetField('Y', gcp.GCPY)
+        feat.SetField('Z', gcp.GCPZ)
+        geom.SetPoint(0, gcp.GCPPixel, gcp.GCPLine)
 
-    feat.SetGeometryDirectly( geom )
-    layer.CreateFeature( feat )
+    feat.SetField('Id', gcp.Id)
+    feat.SetField('Info', gcp.Info)
+
+    feat.SetGeometryDirectly(geom)
+    layer.CreateFeature(feat)
 
 feat = None
 ds.Destroy()
-
-
